# -*- coding: utf-8 -*-
"""Controllers for the tgapp-registration pluggable application."""

from .root import RootController
